@@ -4,6 +4,7 @@ Usage:
   pytmux list
   pytmux run <config>
   pytmux edit <config> [--copy <other_config>]
+  pytmux doctor
   pytmux -h | --help
   pytmux --version
 
@@ -12,6 +13,7 @@ Commands:
   run <config>    Runs the specified config.
   edit <config>   Edits the specified config, with --copy will make a new
                   config based on the one specified.
+  doctor          Validates all of you configs.
 
 Options:
   -h --help       Show this screen.
@@ -23,7 +25,8 @@ from os import makedirs, path
 from docopt import docopt
 
 from __init__ import __version__
-from core import config_dir, edit_config, list_configs, run_config
+from core import (config_dir, doctor_command, edit_config, list_configs,
+                  run_config)
 
 
 def main():
@@ -39,3 +42,5 @@ def main():
     elif arguments['edit']:
         edit_config(arguments['<config>'], arguments['--copy'],
                     arguments['<other_config>'])
+    elif arguments['doctor']:
+        doctor_command()
